--[[

**************************************************************************
* PalaReminder
* by evil.oz
*
* v1.7
*************************************************************************

v1.7
----
no more spam (aura/fury) when u are resting (clearly out of combat)

v1.6
----
added seal support
code optimization and cleanup


Addon that warns fellow paladins about the following: 

you have crusader aura when entering in combat unmounted
you have no aura when buffs changed
you dont have righteous fury and u are probably in tanking gear (only in group)
you dont have a seal when engaging melee


]]--


-- #########################################################################################################
-- onload handler
-- #########################################################################################################
function PalaReminder_OnLoad()

	local cls, class = UnitClass("player");

	if (class == "PALADIN") then
		this:RegisterEvent("PLAYER_REGEN_DISABLED");
		this:RegisterEvent("VARIABLES_LOADED");
		this:RegisterEvent("UNIT_AURA");
		this:RegisterEvent("PLAYER_ENTER_COMBAT");
		this:RegisterEvent("PLAYER_LEAVE_COMBAT");

		PalaReminder_Crusader="Crusader Aura"
		PalaReminder_Fury="Righteous Fury"
		PalaReminder_Aura="Aura"
		PalaReminder_Seal="Seal of "
		PalaReminder_MeleeCombat=false
	else 
		DEFAULT_CHAT_FRAME:AddMessage("PalaReminder disabled, not a paladin", 1.0, 1.0, 0.0);
	end

end




-- #########################################################################################################
-- main event routine
-- #########################################################################################################
function PalaReminder_OnEvent(event)


	if (event == "VARIABLES_LOADED") then
		DEFAULT_CHAT_FRAME:AddMessage("PalaReminder loaded sucessful", 1.0, 1.0, 0.0);
	end

	if (event == "PLAYER_ENTER_COMBAT") then              --entering melee atack
		PalaReminder_MeleeCombat=true
	end

	if (event == "PLAYER_LEAVE_COMBAT") then
		PalaReminder_MeleeCombat=false
	end

	if (event == "PLAYER_REGEN_DISABLED") then            --entering combat

		if  not(UnitInVehicle("player"))  then 
			
			local buffs = PalaReminder_Buffs()
			PalaReminder_CheckCrusader(buffs)
			PalaReminder_CheckAnyAura(buffs)
			PalaReminder_CheckFury(buffs)
			PalaReminder_CheckSeal(buffs)

		end
	end

	if (event == "UNIT_AURA") then                         --buff changed

		if (arg1=="player") then 		


			if not(UnitInVehicle("player")) then

				local buffs = PalaReminder_Buffs()
				PalaReminder_CheckAnyAura(buffs)
				PalaReminder_CheckFury(buffs)
				PalaReminder_CheckSeal(buffs)
			end
		end
	end

end



function PalaReminder_CheckSeal(buffs)

	if (buffs) and (buffs~="") then

		local i=string.find(buffs,PalaReminder_Seal)
		if (not i) and PalaReminder_MeleeCombat then 
			PalaReminder_Message("NO SEAL ACTIVE!!");
			PlaySoundFile("Sound\\interface\\mapping.wav")
		end
	end

end


function  PalaReminder_CheckAnyAura(buffs)

	if (buffs) and (buffs~="") then
		
		local i=string.find(buffs,PalaReminder_Aura)
		if (not i)  and not(IsResting()) then
			PalaReminder_Message("NO AURA SET!!");
			PlaySoundFile("Sound\\interface\\mapping.wav")
		end
	end
end


function  PalaReminder_CheckFury(buffs)

	if (buffs) and (buffs~="") then

		local def=GetCombatRatingBonus(2)  --CR_DEFENSE_SKILL
		local ingroup=GetNumPartyMembers() + GetNumRaidMembers()

		if (def > 25) and (ingroup>0) and not(IsResting()) then
			local i=string.find(buffs,PalaReminder_Fury)
			if (not i) then
				PalaReminder_Message("NO RIGHTEOUS FURY!!");
				PlaySoundFile("Sound\\interface\\mapping.wav")
			end
		end
	end
end

function PalaReminder_CheckCrusader(buffs)

	if (buffs) and (buffs~="") then

		local i=string.find(buffs,PalaReminder_Crusader)
		if (i) then
			if not IsMounted() then
				PalaReminder_Message("CRUSADER AURA!!");
				PlaySoundFile("Sound\\interface\\mapping.wav")
			end
		end
	end

end


function PalaReminder_Buffs()

	local i,x =  1,"";

	while (UnitBuff("player",i) ~= nil) do
		x = x .. UnitBuff("player",i) .. " ";
		i = i + 1;
	end

	return  x, i

end



-- #########################################################################################################
-- misc service functions
-- #########################################################################################################


function PalaReminder_Message(msg)
	UIErrorsFrame:AddMessage(msg, 0, 1.0, 1.0, 1.0, 1);
end
